@@ -1,5 +1,7 @@
 import re
 
+from django.db import connection
+
 
 def uncapitalize(str):
     return str[0:1].lower() + str[1:]
@@ -23,6 +25,18 @@ def null2blanck(str):
     return '' if str == 'null' else str
 
 
+def ExecuteStroredPros(storedProcName, parametrs):
+    c = connection.cursor()
+    try:
+        c.execute("BEGIN")
+        res = c.callproc(storedProcName, parametrs)
+        # results = c.fetchone()
+        c.execute("COMMIT")
+        # return results
+    finally:
+        c.close()
+
+
 class Common:
     @staticmethod
     def get_size_file_str(value):
