@@ -2,7 +2,7 @@ import logging
 from typing import List
 
 from bitfield import Bit, BitHandler
-from django.core.exceptions import EmptyResultSet, FieldError
+from django.core.exceptions import EmptyResultSet
 from django.db import connection, transaction
 from django.db.models import Manager, QuerySet, Q, ForeignKey
 from django.forms import model_to_dict
@@ -575,16 +575,6 @@ class CommonManager(Manager):
 
     def _dataIsArray(self, data):
         return isinstance(data, list)
-        # if not isinstance(data, dict):
-        #     return False
-        #
-        # i = 0
-        # for key in data.keys():
-        #     if key not in ['Class', 'localeStringFormatter']:
-        #         if key != str(i):
-        #             return False
-        #         i += 1
-        # return True
 
     def _remove_prop(self, data, removed):
         if isinstance(data, dict) and isinstance(removed, list):
